---
name: Bug report
about: Report a bug involving Interchange

---

**Description**

Please describe what you were trying to do, what you expected to happen, and what happened instead.

**Reproduction**

Please include a [minimally reproducing example](https://stackoverflow.com/help/minimal-reproducible-example) of this bug.

**Output**

Please include the output, including full tracebacks of any errors, resulting from the reproduction.

**Software versions**

- Which operating system and version are you using?
- How did you install Interchange?
- What is the output of running `conda list`?
